@@ -2,11 +2,11 @@
 
 import gettext
 
-VERSION = "3.2.1"
+VERSION = "3.3.2"
 PACKAGE = "gedit-latex"
-PACKAGE_STRING = "gedit-latex 3.2.1"
+PACKAGE_STRING = "gedit-latex 3.3.2"
 GETTEXT_PACKAGE = "gedit-latex"
-GL_LOCALEDIR = "/usr/share/locale"
+GL_LOCALEDIR = "/opt/gnome/share/locale"
 
 try:
     gettext.bindtextdomain(GETTEXT_PACKAGE, GL_LOCALEDIR)
